#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys, os
import json

sys.path.append('/home/geoint/GeoSentinel')
from geosentinel import APISentinel
from geosentinel import polygonToBox

from datetime import date 


def findSentinelProducts(wkt, startDate, endDate, platform, cloud):
	sentinel = APISentinel.APISentinel('asalazarg',  'geo135asg')

	products = sentinel.getProducts(wkt, (startDate, endDate), {"platformname":platform, "cloudcoverpercentage":"[0 TO "+str(cloud)+"]"})

	return products

def main(argv):

	if len(sys.argv) != 2:
		print("Usage: " + argv[0] + " <JSON File>")
	else:
		jsonFile=open(argv[1]).read()
		cfg = json.loads(jsonFile)

		wkt = polygonToBox.getWKTPolygonBoundingBox(cfg['wkt'], True)
		productList = findSentinelProducts(wkt, cfg['startDate'], cfg['endDate'], cfg['platform'], cfg['clouds'])

 		productsCodes = {"L2A":"L1C"}
		fileNames = [productList[k]['filename'].replace("SAFE", "zip").replace(productsCodes[cfg['productLevel']], cfg['productLevel']) for k in productList.keys() ]
		print(fileNames)
		inDir =  cfg["productsDir"]
		outdir =  cfg["linksDir"]
		dirList = os.listdir(inDir)
		
		matchingProducts = set(fileNames).intersection(set(dirList))
		print ( str(len(matchingProducts))+" of " + str(len(fileNames)) +" products found.")	


		for f in matchingProducts:
			print (f)
			os.system("ln -s " + inDir+f + " " + outdir+f)
		print (str(len(matchingProducts)) + " Linked to " + outdir)
		
if __name__ == "__main__":
	main(sys.argv)


#cat results2.txt | xargs -I{} ln -s {} ~/newlinks

